@@ -14,6 +14,7 @@
 
 import json
 from datetime import timedelta
+from pathlib import Path
 from typing import Any, Dict, List, Optional
 
 from robot.utils import get_link_path  # type: ignore
@@ -228,6 +229,26 @@ class PlaywrightState(LibraryComponent):
                         response = stub.ClosePage(Request().Empty())
                         logger.info(response.log)
 
+    @keyword(tags=("Setter", "BrowserControl"))
+    def connect_to_browser(
+        self, wsEndpoint: str, browser: SupportedBrowsers = SupportedBrowsers.chromium
+    ):
+        """Connect to a playwright Browser.
+        See `Browser, Context and Page` for more information about Browser and related concepts.
+
+        Returns a stable identifier for the connected browser.
+
+        ``wsEndpoint`` Address to connect to.
+
+        ``browser`` Opens the specified browser. Defaults to chromium.
+        """
+        with self.playwright.grpc_channel() as stub:
+            response = stub.ConnectToBrowser(
+                Request().ConnectBrowser(url=wsEndpoint, browser=browser.name)
+            )
+            logger.info(response.log)
+            return response.body
+
     @keyword(tags=("Setter", "BrowserControl"))
     def new_browser(
         self,
@@ -411,7 +432,9 @@ class PlaywrightState(LibraryComponent):
         If all contexts override the proxy, global proxy will be never used and can be any string
 
         ``videosPath`` Enables video recording for all pages to videosPath
-        folder. If not specified, videos are not recorded.
+        folder. If videosPath is not existing folder, videosPath folder is created
+        under ${OUTPUT_DIR}/browser/video/ folder. If videosPath is not specified,
+        videos are not recorded.
 
         ``videoSize`` Specifies dimensions of the automatically recorded
         video. Can only be used if videosPath is set. If not specified the size will
@@ -438,6 +461,7 @@ class PlaywrightState(LibraryComponent):
         If there's no open Browser this keyword will open one. Does not create pages.
         """
         params = locals_to_params(locals())
+        params = self._set_video_path(params)
         params = convert_typed_dict(self.new_context.__annotations__, params)
         if not videosPath:
             params.pop("videoSize", None)
@@ -455,6 +479,15 @@ class PlaywrightState(LibraryComponent):
         self.context_cache.add(response.body, self._get_video_size(params))
         return response.body
 
+    def _set_video_path(self, params):
+        video_path = params.get("videosPath")
+        if not video_path:
+            return params
+        if Path(video_path).is_dir():
+            return params
+        params["videosPath"] = self.video_output / video_path
+        return params
+
     def _get_video_size(self, params: dict) -> dict:
         if "videoSize" in params:
             return params["videoSize"]
@@ -653,8 +686,8 @@ class PlaywrightState(LibraryComponent):
 
 
         ``browser`` Defaults to ``ALL``
-        - ``ALL`` Returns all ids as a list.
-        - ``ACTIVE`` or ``CURRENT`` Returns the id of the currently active browser as list.
+        - ``ALL`` / ``ANY`` Returns all ids as a list.
+        - ``ACTIVE`` / ``CURRENT`` Returns the id of the currently active browser as list.
 
         The ACTIVE browser is a synonym for the CURRENT Browser.
         """
@@ -675,6 +708,8 @@ class PlaywrightState(LibraryComponent):
         """Returns a list of context ids based on the browser selection.
         See `Browser, Context and Page` for more information about Context and related concepts.
 
+        ``ALL`` and ``ANY`` are synonyms.
+        ``ACTIVE`` and ``CURRENT`` are also synonyms.
 
         ``context`` Defaults to ``ALL``
         - ``ALL`` Returns all context ids as a list.
@@ -719,6 +754,8 @@ class PlaywrightState(LibraryComponent):
         """Returns a list of page ids based on the context and browser selection.
         See `Browser, Context and Page` for more information about Page and related concepts.
 
+        ``ALL`` and ``ANY`` are synonyms.
+        ``ACTIVE`` and ``CURRENT`` are also synonyms.
 
         ``page``
         - ``ALL`` Returns all page ids as a list.
@@ -732,6 +769,15 @@ class PlaywrightState(LibraryComponent):
         - ``ALL`` page ids from all open browsers shall be fetched.
         - ``ACTIVE`` only page ids from the active browser shall be fetched.
 
+        Example:
+        | Test Case
+        |     `New Page`    http://www.imbus.de
+        |     `New Page`    http://www.reaktor.com
+        |     ${current_page}=   Get Page IDs    ACTIVE    ACTIVE    ACTIVE
+        |     Log                Current page ID is: ${current_page}[0]
+        |     ${all_pages}=      Get Page IDs    CURRENT   CURRENT   ALL
+        |     Log Many           These are all Page IDs    @{all_pages}
+
         The ACTIVE page of the ACTIVE context of the ACTIVE Browser is the ``Current`` Page.
         """
         if browser == SelectionType.ACTIVE:
